\name{NADA-internal}
\title{Internal NADA Objects}
\alias{.trueT}
\alias{.cohnN}
\description{
  Internal NADA functions.
}
\usage{
.trueT(x)
.cohnN(uncen, cen)
}

\details{
  These are not to be called by the user.
}
\keyword{internal}


\eof
\name{NADA.Ag}
\alias{NADA.Ag}
\docType{data}
\alias{Ag}
\alias{silver}
\title{Dissolved silver concentrations from water analyses} 
\description{
    This dataset was used by Helsel and Cohn (1988) to verify their
    software.  It is provided for code validation purposes.
}
\usage{data(NADA.Ag)}
\format{
    A list containing 56 observations with items `obs' and `censored'.
    `obs' is a numeric vector of all observations (both censored
    and uncensored).  `censored' is a logical vector indicating where
    an element of `obs' is censored (a less-than value).
}
\source{Helsel and Cohn (1988)}
\references{
    Dennis R. Helsel and Timothy A. Cohn (1988), Estimation of descriptive
    statistics for multiply censored water quality data, Water Resources
    Research vol. 24, no. 12, pp.1997-2004 
}
\keyword{datasets}

\eof
\name{NADA.As}
\alias{NADA.As}
\docType{data}
\alias{As}
\alias{arsenic}
\title{Dissolved arsenic concentrations in ground water of U.S.}
\description{
    This dataset is a random selection of dissolved arsenic analyses taken
    during the U.S. Geological Survey's National Water Quality Assessment
    program (NAWQA).  
}
\usage{data(NADA.As)}
\format{
    A list containing 50 observations with items `obs' and `censored'.
    `obs' is a numeric vector of all arsenic observations (both censored
    and uncensored).  `censored' is a logical vector indicating where
    an element of `obs' is censored (a less-than value).
}
\source{U.S. Geological Survey National Water Quality Assessment
        Data Warehouse}
\references{
    The USGS NAWQA site at \url{http://water.usgs.gov/nawqa}
}
\keyword{datasets}

\eof
\name{hc.ppoints} 
\alias{hc.ppoints}
\alias{hc.ppoints.uncen}
\alias{hc.ppoints.cen}
\title{Helsel-Cohn style plotting positions} 
\description{
    Helsel-Cohn style plotting positions for multiply-censored data.
}
\usage{
    hc.ppoints(obs, censored)
    hc.ppoints.uncen(obs, censored, cn)
    hc.ppoints.cen(obs, censored, cn)
}
\arguments{
        \item{obs}{
            A numeric vector of observations.  This includes both censored
	        and uncensored observations.
        } 
        \item{censored}{
            A logical vector indicating TRUE where an observation in v is
	        censored (a less-than value) and FALSE otherwise.
        }
        \item{cn}{
            An optional argument for internal-code use only.
            cn = a Cohn Numbers list (quantities described by 
            Helsel and Cohn (1988) in their formulation of the problem).
        }
} 
\details{
    The function computes Wiebull-type plotting postions of data
    containing mixed uncensored and censored data.  The formula was first
    described by Hirsch and Stedinger (1897) and latter reformulated by
    Helsel and Cohn (1988).  It assumes that censoring is left-censoring
    (less-thans).  A detailed discussion of the formulation is in Lee
    and Helsel (in press).

    Note that if the input vector `censored' is of zero length, then
    the plotting positions are calculated using \code{ppoints}.
    Otherwise, \code{hc.ppoints.uncen} and \code{hc.ppoints.cen}
    are used.

    \code{hc.ppoints.uncen} calculates plotting positions for uncensored 
    data only.

    \code{hc.ppoints.cen} calculates plotting positions for censored 
    data only.
}
\value{
    \code{hc.ppoints} returns a numeric vector of plotting positions
    which correspond to the observations in the input vector 'obs'.

    \code{hc.ppoints.uncen} returns a numeric vector of plotting positions
    which correspond to the uncensored observations in the input vector 'obs'.

    \code{hc.ppoints.cen} returns a numeric vector of plotting positions
    which correspond to the censored observations in the input vector 'obs'.
} 
\references{

    Lee and Helsel (in press), Statistical analysis of environmental data
    containing multiple detection limits: S-language software for linear
    regression on order statistics, Computers in Geoscience vol. X, pp. X-X

    Dennis R. Helsel and Timothy A. Cohn (1988), Estimation of descriptive
    statistics for multiply censored water quality data, Water Resources
    Research vol. 24, no. 12, pp.1997-2004 

    Robert M. Hirsch and Jery R. Stedinger (1987), Plotting positions
    for historical floods and their precision. Water Resources Research,
    vol. 23, no. 4, pp. 715-727.
} 
\author{
    Lopaka(Rob) Lee <rclee@usgs.gov>
} 
\seealso{
    \code{\link{ros}}, \code{\link{splitQual}}
}
\examples{
    obs      = c(0.5,    0.5,   1.0,  1.5,   5.0,    10,   100)
    censored = c(TRUE, FALSE, FALSE, TRUE, FALSE, FALSE, FALSE)

    hc.ppoints(obs, censored) 
} 
\keyword{regression} 

\eof
\name{pct.censored} 
\alias{pct.censored} 
\title{Calculate the percentage of values censored} 
\description{
    \code{pct.censored} is a simple, but convenient, function that calculates
    the percentage of censored values.  It is designed to work similar
    to other NADA ROS functions.
} 
\usage{ pct.censored(obs, censored)} 
\arguments{
        \item{obs}{
            A numeric vector of observations.  This includes both censored
	        and uncensored observations.
        } 
        \item{censored}{
            A logical vector indicating TRUE where an observation in v is
	        censored (a less-than value) and FALSE otherwise.
        } 
} 
\details{
    100*(length(obs[censored])/length(obs))
}

%% Function return values 
\value{
    \code{pct.censored} returns a single numeric value representing
    the percentage of values censored in the ``obs" vector.
} 
\author{
    Lopaka(Rob) Lee <rclee@usgs.gov>
} 
\seealso{
    \code{\link{splitQual}}, \code{\link{ros}}, 
}
\examples{
    obs      = c(0.5,    0.5,   1.0,  1.5,   5.0,    10,   100)
    censored = c(TRUE, FALSE, FALSE, TRUE, FALSE, FALSE, FALSE)

    pct.censored(obs, censored) 
} 
\keyword{utilities} 

\eof
\name{predict.ros} 

\alias{predict.ros} 
\alias{quantile.ros} 

\alias{mean.ros}
\alias{median}
\alias{median.default}
\alias{median.ros}
\alias{sd}
\alias{sd.default}
\alias{sd.ros}

\title{Query and Prediction with ROS models} 
\description{
    Functions that perform query and/or prediction with Regression
    on Order Statistics (\code{\link{ros}}) objects.

    \code{mean} returns the modeled mean of a ROS model.
    \code{median} returns the modeled median of a ROS model.
    \code{sd} returns the modeled standard deviation of a ROS model.
 
    \code{quantile} produces sample quantiles corresponding to
    the given probabilities. The smallest observation corresponds to a
    probability of 0 and the largest to a probability of 1.

    \code{predict} Predicted values based on a ROS model object.
} 
\usage{
    \method{mean}{ros}(x, ...)
    \method{median}{ros}(x, na.rm=FALSE)
    \method{sd}{ros}(x, na.rm=FALSE)
    \method{quantile}{ros}(x, probs=c(0.05, 0.10, 0.25, 0.50, 0.75, 0.90, 0.95), ...)
    \method{predict}{ros}(object, newdata, ...)
}
\arguments{
    \item{x, object}{
        A ROS model constructed using \code{\link{ros}}
    }
    \item{na.rm}{
        logical. Should missing values be removed?
    }
    \item{probs}{
        Numeric vector with values in [0,1] -- the quantiles to predict.
    }
    \item{newdata}{
        Numeric vector of normalized quantiles of plotting positions.
    }
    \item{...}{
        Additional arguments passed to the generic method.
    }
}
\details{
}

\value{
    All functions return a numeric vector of results.
} 
\references{

    Lee and Helsel (in press) Statistical analysis of environmental data
    containing multiple detection limits: S-language software for 
    regression on order statistics, Computers in Geoscience vol. X, pp. X-X

    Lee and Helsel (in press) Baseline models of trace elements in
    major aquifers of the United States. Applied Geochemistry vol. X, pp. X-X.

    Dennis R. Helsel (2004), Nondetects And Data Analasis:
    John Wiley and Sons, New York.

    Dennis R. Helsel (1990), Less Than Obvious: Statistical Methods for,
    Environmental Science and Technology,
    vol.24, no. 12, pp. 1767-1774

    Dennis R. Helsel and Timothy A. Cohn (1988), Estimation of descriptive
    statistics for multiply censored water quality data, Water Resources
    Research vol. 24, no. 12, pp.1997-2004 
} 
\author{
    Lopaka(Rob) Lee <rclee@usgs.gov>
} 
\seealso{
    \code{\link{ros}}
    \code{\link{hc.ppoints}}
}
\note{
    Some of these fuctions mask the original functions in the base
    package.  For the documentation on the original functions use:
    \code{help("foo", package="base")}
}
\examples{
    obs      = c(0.5,    0.5,   1.0,  1.5,   5.0,    10,   100)
    censored = c(TRUE, FALSE, FALSE, TRUE, FALSE, FALSE, FALSE)

    myros = ros(obs, censored) 

    mean(myros)
    median(myros) 
    sd(myros)
 
    quantile(myros, probs=c(0.90, 0.95))
    predict(myros, 1.5)
} 
\keyword{regression} 

\eof
\name{ros} 
\alias{ros} 
\alias{lros} 
\alias{print.ros}
\alias{as.data.frame.ros}
\title{Regression on Order Statistics} 
\description{
    \code{ros} is an implementation of a Regression on Order Statistics
    (ROS) designed for multiply censored analytical chemistry data.

    The method assumes data contains zero to many left censored (less-than)
    values.

    By default, \code{ros} performs a log transformation prior to, 
    and after operations over the data.
} 
\usage{ ros(obs, censored, forwardT="log", reverseT="exp")} 
\arguments{
        \item{obs}{
            A numeric vector of observations.  This includes both censored
	        and uncensored observations.
        } 
        \item{censored}{
            A logical vector indicating TRUE where an observation in v is
	        censored (a less-than value) and FALSE otherwise.
        } 
        \item{forwardT}{
	        A name of a function to use for transformation prior to performing
	        the ROS fit.  Defaults to \code{log}.
        } 
        \item{reverseT}{
	        A name of a function to use for reversing the transformation
	        after performing the ROS fit. Defaults to \code{exp}.
        }

} 
\details{

    The proceedure first computes the Weibull-type plotting positions of
    the combined uncensored and censored observations using a formula
    designed for multiply-censored data (see \code{hc.ppoints}).
    A linear regression is formed using the plotting positions of the
    uncensored observations and their normal quantiles.  This model is
    then used to estimate the concentration of the censored observations
    as a function of their normal quantiles.  Finally, the observed
    uncensored values are combined with modeled censored values to
    corporately estimate summary statistics of the entire population. By
    combining the uncensored values with modeled censored values, this
    method is more resistant of any non-normality of errors, and reduces
    any transformation errors that may be incurred.

}

%% Function return values 
\value{
    \code{ros} returns an object of class c("ros", "lm").

    \code{print} displays a simple summary of the ROS model.
    \code{as.data.frame} converts the modeled data in a ROS model to
    a data frame. Note that this discards all linear-model information
    from the object.
} 
\references{

    Lee and Helsel (in press) Statistical analysis of environmental data
    containing multiple detection limits: S-language software for linear
    regression on order statistics, Computers in Geoscience vol. X, pp. X-X

    Lee and Helsel (in press) Baseline models of trace elements in
    major aquifers of the United States. Applied Geochemistry vol. X, pp. X-X.

    Dennis R. Helsel (2004), Nondetects And Data Analasis:
    John Wiley and Sons, New York.

    Dennis R. Helsel (1990), Less Than Obvious: Statistical Methods for,
    Environmental Science and Technology,
    vol.24, no. 12, pp. 1767-1774

    Dennis R. Helsel and Timothy A. Cohn (1988), Estimation of descriptive
    statistics for multiply censored water quality data, Water Resources
    Research vol. 24, no. 12, pp.1997-2004 
} 
\author{
    Lopaka(Rob) Lee <rclee@usgs.gov>
} 
\seealso{
    \code{\link{splitQual}}, \code{\link{predict.ros}}, 
    \code{\link{plot.ros}}, \code{\link{summary.ros}}
}
\examples{
    obs      = c(0.5,    0.5,   1.0,  1.5,   5.0,    10,   100)
    censored = c(TRUE, FALSE, FALSE, TRUE, FALSE, FALSE, FALSE)

    myros = ros(obs, censored) 

    summary(myros)
    as.data.frame(myros)
} 
\keyword{regression} 

\eof
\name{splitQual} 
\alias{splitQual} 
\title{Split character qualifiers and numeric values from qualified data} 
\description{
    \code{splitQual} extracts qualifed and unqualifed vectors 
    from a character vector containing concatenated 
    numeric and qualifying characters.

    Typically used to split ``less-thans" in qualifier-numeric 
    concantenations like ``<0.5".
}
\usage{ splitQual(v, qual.symbol= "<") } 
\arguments{
        \item{v}{
            A character vector.
        } 
        \item{qual.symbol}{
            The qualifier symbol to split from the characters in v.
            Defaults to ``<".
        }
}
\value{
    \code{splitQual} returns a list of three vectors.

    \item{qual}{
        A numeric vector of values associated with qualifed input.
    }
    \item{unqual}{
        A numeric vector of values associated with unqualified input 
    }
    \item{qual.index}{
        Indexes of qualified values (ie., where qual.symbol was matched)
    }
}
\references{

    Lee and Helsel (in press), Statistical analysis of environmental data
    containing multiple detection limits: S-language software for
    regression on order statistics, Computers in Geoscience vol. X, pp. X-X
} 
\author{
    Lopaka(Rob) Lee <rclee@usgs.gov>
} 
\examples{
    v = c('<1', 1, '<1', 1, 2)
    splitQual(v)
} 
\keyword{utilities} 

\eof
\name{summary.ros} 
\alias{summary.ros} 
\alias{plot.ros} 
\alias{abline} 
\alias{abline.default} 
\alias{abline.ros} 
\title{Summary and Plotting of Regression on Order Statistics models} 
\description{
    Generic implementations of summary and plotting functions for ROS models.
    
    \code{summary.ros} provides the standard summary of the linear model.
    Has the option of producing the standard linear-model quality plots.

    \code{plot.ros} constructs a probability plot representation of
    the ROS model.

    \code{abline.ros} adds a line representing the linear regression model
    to an existing ROS prob-plot -- For comparing two or more ROS models.
} 
\usage{
    \method{summary}{ros}(object, plot=FALSE, ...) 
    \method{plot}{ros}(x, plot.censored=FALSE, lm.line=TRUE, grid=TRUE, ylab="Value", pch=16, ...)
    \method{abline}{ros}(a, ...)
}
\arguments{

%% summary.ros arguments
    \item{object}{
        A ROS model constructed using \code{\link{ros}}
    }
    \item{plot}{
        Logical indicating whether the standard \code{\link{lm}} quality plots
        should be drawn.
    }

%% plot.ros arguments
    \item{x}{
        A ROS model constructed using \code{\link{ros}}
    }
    \item{plot.censored}{
        A logical indicating if the modeled censored values should
        be plotted.
    }
    \item{lm.line}{
        A logical indicating if the a line (abline) representing the
        linear regression model should be drawn on the plot.
    }
    \item{grid}{
        A logical indicating if dotted lines are to be drawn
        at major axis division.
    }
    \item{ylab}{
        A character string for the y-axis lable.
    }
    \item{pch}{
        The numerical code of the plotting symbols for the uncensored data.
        See \code{\link{par}}
    }

    \item{...}{
        Additional arguments passed to the generic method.
    }

    \item{a}{
        A ROS model constructed using \code{\link{ros}}
    }
 
}
\details{
}

%% Function return values 
%\value{
%} 
\references{

    Lee and Helsel (in press) Statistical analysis of environmental data
    containing multiple detection limits: S-language software for 
    regression on order statistics, Computers in Geoscience vol. X, pp. X-X

    Lee and Helsel (in press) Baseline models of trace elements in
    major aquifers of the United States. Applied Geochemistry vol. X, pp. X-X.

    Dennis R. Helsel (2004), Nondetects And Data Analasis:
    John Wiley and Sons, New York.

    Dennis R. Helsel (1990), Less Than Obvious: Statistical Methods for,
    Environmental Science and Technology,
    vol.24, no. 12, pp. 1767-1774

    Dennis R. Helsel and Timothy A. Cohn (1988), Estimation of descriptive
    statistics for multiply censored water quality data, Water Resources
    Research vol. 24, no. 12, pp.1997-2004 
} 
\author{
    Lopaka(Rob) Lee <rclee@usgs.gov>
} 
\seealso{
    \code{\link{ros}},
    \code{\link{predict.ros}},
    \code{\link{quantile.ros}},
    \code{\link{sd.ros}},
    \code{\link{mean.ros}},
    \code{\link{median.ros}}
}
\examples{
    obs      = c(0.5,    0.5,   1.0,  1.5,   5.0,    10,   100)
    censored = c(TRUE, FALSE, FALSE, TRUE, FALSE, FALSE, FALSE)

    myros = ros(obs, censored) 
    summary(myros, plot=TRUE) # Cycles through standard lm() plots

    plot(myros, plot.cen=TRUE) # Forms a prob-plot of the ROS model

    obs2      = c(0.5,    1.0,  1.5,   1.5,    10,   100,   200)
    censored2 = c(TRUE, FALSE, TRUE, FALSE, FALSE, FALSE, FALSE)

    abline(ros(obs2, censored2)) # Draws this regression line on existing plot
} 
\keyword{regression} 

\eof
